gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] branch master updated: address API stability FIXMEs in


From: gnunet
Subject: [taler-exchange] branch master updated: address API stability FIXMEs in taler_exchange_service
Date: Sun, 04 Jun 2023 14:11:33 +0200

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository exchange.

The following commit(s) were added to refs/heads/master by this push:
     new 0ad3de93 address API stability FIXMEs in taler_exchange_service
0ad3de93 is described below

commit 0ad3de938e37cd4f34dd791283350ccfc09df2db
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Sun Jun 4 14:10:54 2023 +0200

    address API stability FIXMEs in taler_exchange_service
---
 src/exchange-tools/taler-auditor-offline.c         |   5 +-
 src/exchange-tools/taler-exchange-offline.c        |  29 +++--
 src/include/taler_exchange_service.h               | 119 +++++++++++++++++----
 src/lib/exchange_api_add_aml_decision.c            |  26 ++---
 src/lib/exchange_api_auditor_add_denomination.c    |  34 +++---
 src/lib/exchange_api_management_add_partner.c      |  26 ++---
 src/lib/exchange_api_management_auditor_disable.c  |  26 ++---
 src/lib/exchange_api_management_auditor_enable.c   |  22 ++--
 src/lib/exchange_api_management_post_extensions.c  |   4 +-
 src/lib/exchange_api_management_set_global_fee.c   |  26 ++---
 src/lib/exchange_api_management_set_wire_fee.c     |  26 ++---
 src/testing/testing_api_cmd_auditor_add.c          |   8 +-
 .../testing_api_cmd_auditor_add_denom_sig.c        |   8 +-
 src/testing/testing_api_cmd_auditor_del.c          |   9 +-
 src/testing/testing_api_cmd_set_wire_fee.c         |   5 +-
 src/testing/testing_api_cmd_take_aml_decision.c    |  10 +-
 16 files changed, 237 insertions(+), 146 deletions(-)

diff --git a/src/lib/exchange_api_add_aml_decision.c 
b/src/lib/exchange_api_add_aml_decision.c
index 7245db3b..342e1e3d 100644
--- a/src/lib/exchange_api_add_aml_decision.c
+++ b/src/lib/exchange_api_add_aml_decision.c
@@ -79,9 +79,9 @@ handle_add_aml_decision_finished (void *cls,
 {
   struct TALER_EXCHANGE_AddAmlDecision *wh = cls;
   const json_t *json = response;
-  struct TALER_EXCHANGE_HttpResponse hr = {
-    .http_status = (unsigned int) response_code,
-    .reply = json
+  struct TALER_EXCHANGE_AddAmlDecisionResponse adr = {
+    .hr.http_status = (unsigned int) response_code,
+    .hr.reply = json
   };
 
   wh->job = NULL;
@@ -89,34 +89,34 @@ handle_add_aml_decision_finished (void *cls,
   {
   case 0:
     /* no reply */
-    hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
-    hr.hint = "server offline?";
+    adr.hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
+    adr.hr.hint = "server offline?";
     break;
   case MHD_HTTP_NO_CONTENT:
     break;
   case MHD_HTTP_FORBIDDEN:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_CONFLICT:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   default:
     /* unexpected response code */
     GNUNET_break_op (0);
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Unexpected response code %u/%d for exchange AML decision\n",
                 (unsigned int) response_code,
-                (int) hr.ec);
+                (int) adr.hr.ec);
     break;
   }
   if (NULL != wh->cb)
   {
     wh->cb (wh->cb_cls,
-            &hr);
+            &adr);
     wh->cb = NULL;
   }
   TALER_EXCHANGE_add_aml_decision_cancel (wh);
diff --git a/src/lib/exchange_api_auditor_add_denomination.c 
b/src/lib/exchange_api_auditor_add_denomination.c
index 71f421d4..89de0d7f 100644
--- a/src/lib/exchange_api_auditor_add_denomination.c
+++ b/src/lib/exchange_api_auditor_add_denomination.c
@@ -79,9 +79,9 @@ handle_auditor_add_denomination_finished (void *cls,
 {
   struct TALER_EXCHANGE_AuditorAddDenominationHandle *ah = cls;
   const json_t *json = response;
-  struct TALER_EXCHANGE_HttpResponse hr = {
-    .http_status = (unsigned int) response_code,
-    .reply = json
+  struct TALER_EXCHANGE_AuditorAddDenominationResponse adr = {
+    .hr.http_status = (unsigned int) response_code,
+    .hr.reply = json
   };
 
   ah->job = NULL;
@@ -90,37 +90,37 @@ handle_auditor_add_denomination_finished (void *cls,
   case MHD_HTTP_NO_CONTENT:
     break;
   case MHD_HTTP_FORBIDDEN:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_NOT_FOUND:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_GONE:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_PRECONDITION_FAILED:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   default:
     /* unexpected response code */
     if (NULL != json)
     {
-      hr.ec = TALER_JSON_get_error_code (json);
-      hr.hint = TALER_JSON_get_error_hint (json);
+      adr.hr.ec = TALER_JSON_get_error_code (json);
+      adr.hr.hint = TALER_JSON_get_error_hint (json);
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                   "Unexpected response code %u/%d for exchange 
auditor-add-denomination at URL `%s'\n",
                   (unsigned int) response_code,
-                  (int) hr.ec,
+                  (int) adr.hr.ec,
                   ah->url);
     }
     else
     {
-      hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
-      hr.hint = NULL;
+      adr.hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
+      adr.hr.hint = NULL;
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                   "Unexpected HTTP response code %u (no JSON returned) at URL 
`%s'\n",
                   (unsigned int) response_code,
@@ -131,7 +131,7 @@ handle_auditor_add_denomination_finished (void *cls,
   if (NULL != ah->cb)
   {
     ah->cb (ah->cb_cls,
-            &hr);
+            &adr);
     ah->cb = NULL;
   }
   TALER_EXCHANGE_add_auditor_denomination_cancel (ah);
diff --git a/src/lib/exchange_api_management_add_partner.c 
b/src/lib/exchange_api_management_add_partner.c
index 75fb8aa6..fec66c56 100644
--- a/src/lib/exchange_api_management_add_partner.c
+++ b/src/lib/exchange_api_management_add_partner.c
@@ -79,9 +79,9 @@ handle_add_partner_finished (void *cls,
 {
   struct TALER_EXCHANGE_ManagementAddPartner *wh = cls;
   const json_t *json = response;
-  struct TALER_EXCHANGE_HttpResponse hr = {
-    .http_status = (unsigned int) response_code,
-    .reply = json
+  struct TALER_EXCHANGE_ManagementAddPartnerResponse apr = {
+    .hr.http_status = (unsigned int) response_code,
+    .hr.reply = json
   };
 
   wh->job = NULL;
@@ -89,34 +89,34 @@ handle_add_partner_finished (void *cls,
   {
   case 0:
     /* no reply */
-    hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
-    hr.hint = "server offline?";
+    apr.hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
+    apr.hr.hint = "server offline?";
     break;
   case MHD_HTTP_NO_CONTENT:
     break;
   case MHD_HTTP_FORBIDDEN:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    apr.hr.ec = TALER_JSON_get_error_code (json);
+    apr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_CONFLICT:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    apr.hr.ec = TALER_JSON_get_error_code (json);
+    apr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   default:
     /* unexpected response code */
     GNUNET_break_op (0);
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    apr.hr.ec = TALER_JSON_get_error_code (json);
+    apr.hr.hint = TALER_JSON_get_error_hint (json);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Unexpected response code %u/%d for adding exchange partner\n",
                 (unsigned int) response_code,
-                (int) hr.ec);
+                (int) apr.hr.ec);
     break;
   }
   if (NULL != wh->cb)
   {
     wh->cb (wh->cb_cls,
-            &hr);
+            &apr);
     wh->cb = NULL;
   }
   TALER_EXCHANGE_management_add_partner_cancel (wh);
diff --git a/src/lib/exchange_api_management_auditor_disable.c 
b/src/lib/exchange_api_management_auditor_disable.c
index b1de80f0..8bce7f74 100644
--- a/src/lib/exchange_api_management_auditor_disable.c
+++ b/src/lib/exchange_api_management_auditor_disable.c
@@ -81,9 +81,9 @@ handle_auditor_disable_finished (void *cls,
 {
   struct TALER_EXCHANGE_ManagementAuditorDisableHandle *ah = cls;
   const json_t *json = response;
-  struct TALER_EXCHANGE_HttpResponse hr = {
-    .http_status = (unsigned int) response_code,
-    .reply = json
+  struct TALER_EXCHANGE_ManagementAuditorDisableResponse adr = {
+    .hr.http_status = (unsigned int) response_code,
+    .hr.reply = json
   };
 
   ah->job = NULL;
@@ -92,32 +92,32 @@ handle_auditor_disable_finished (void *cls,
   case MHD_HTTP_NO_CONTENT:
     break;
   case MHD_HTTP_FORBIDDEN:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_NOT_FOUND:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_CONFLICT:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   default:
     /* unexpected response code */
     GNUNET_break_op (0);
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    adr.hr.ec = TALER_JSON_get_error_code (json);
+    adr.hr.hint = TALER_JSON_get_error_hint (json);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Unexpected response code %u/%d for exchange management 
auditor disable\n",
                 (unsigned int) response_code,
-                (int) hr.ec);
+                (int) adr.hr.ec);
     break;
   }
   if (NULL != ah->cb)
   {
     ah->cb (ah->cb_cls,
-            &hr);
+            &adr);
     ah->cb = NULL;
   }
   TALER_EXCHANGE_management_disable_auditor_cancel (ah);
diff --git a/src/lib/exchange_api_management_auditor_enable.c 
b/src/lib/exchange_api_management_auditor_enable.c
index af75215e..65018577 100644
--- a/src/lib/exchange_api_management_auditor_enable.c
+++ b/src/lib/exchange_api_management_auditor_enable.c
@@ -82,9 +82,9 @@ handle_auditor_enable_finished (void *cls,
 {
   struct TALER_EXCHANGE_ManagementAuditorEnableHandle *ah = cls;
   const json_t *json = response;
-  struct TALER_EXCHANGE_HttpResponse hr = {
-    .http_status = (unsigned int) response_code,
-    .reply = json
+  struct TALER_EXCHANGE_ManagementAuditorEnableResponse aer = {
+    .hr.http_status = (unsigned int) response_code,
+    .hr.reply = json
   };
 
   ah->job = NULL;
@@ -93,28 +93,28 @@ handle_auditor_enable_finished (void *cls,
   case MHD_HTTP_NO_CONTENT:
     break;
   case MHD_HTTP_FORBIDDEN:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    aer.hr.ec = TALER_JSON_get_error_code (json);
+    aer.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_CONFLICT:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    aer.hr.ec = TALER_JSON_get_error_code (json);
+    aer.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   default:
     /* unexpected response code */
     GNUNET_break_op (0);
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    aer.hr.ec = TALER_JSON_get_error_code (json);
+    aer.hr.hint = TALER_JSON_get_error_hint (json);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Unexpected response code %u/%d for exchange management 
auditor enable\n",
                 (unsigned int) response_code,
-                (int) hr.ec);
+                (int) aer.hr.ec);
     break;
   }
   if (NULL != ah->cb)
   {
     ah->cb (ah->cb_cls,
-            &hr);
+            &aer);
     ah->cb = NULL;
   }
   TALER_EXCHANGE_management_enable_auditor_cancel (ah);
diff --git a/src/lib/exchange_api_management_post_extensions.c 
b/src/lib/exchange_api_management_post_extensions.c
index b9721a98..99d1653d 100644
--- a/src/lib/exchange_api_management_post_extensions.c
+++ b/src/lib/exchange_api_management_post_extensions.c
@@ -126,7 +126,7 @@ struct TALER_EXCHANGE_ManagementPostExtensionsHandle *
 TALER_EXCHANGE_management_post_extensions (
   struct GNUNET_CURL_Context *ctx,
   const char *url,
-  struct TALER_EXCHANGE_ManagementPostExtensionsData *ped,
+  const struct TALER_EXCHANGE_ManagementPostExtensionsData *ped,
   TALER_EXCHANGE_ManagementPostExtensionsCallback cb,
   void *cb_cls)
 {
@@ -151,7 +151,7 @@ TALER_EXCHANGE_management_post_extensions (
 
   body = GNUNET_JSON_PACK (
     GNUNET_JSON_pack_object_steal ("extensions",
-                                   ped->extensions),
+                                   (json_t *) ped->extensions),
     GNUNET_JSON_pack_data_auto ("extensions_sig",
                                 &ped->extensions_sig));
 
diff --git a/src/lib/exchange_api_management_set_global_fee.c 
b/src/lib/exchange_api_management_set_global_fee.c
index c8fae5c1..518e710c 100644
--- a/src/lib/exchange_api_management_set_global_fee.c
+++ b/src/lib/exchange_api_management_set_global_fee.c
@@ -79,9 +79,9 @@ handle_set_global_fee_finished (void *cls,
 {
   struct TALER_EXCHANGE_ManagementSetGlobalFeeHandle *sgfh = cls;
   const json_t *json = response;
-  struct TALER_EXCHANGE_HttpResponse hr = {
-    .http_status = (unsigned int) response_code,
-    .reply = json
+  struct TALER_EXCHANGE_ManagementSetGlobalFeeResponse sfr = {
+    .hr.http_status = (unsigned int) response_code,
+    .hr.reply = json
   };
 
   sgfh->job = NULL;
@@ -90,32 +90,32 @@ handle_set_global_fee_finished (void *cls,
   case MHD_HTTP_NO_CONTENT:
     break;
   case MHD_HTTP_FORBIDDEN:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    sfr.hr.ec = TALER_JSON_get_error_code (json);
+    sfr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_CONFLICT:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    sfr.hr.ec = TALER_JSON_get_error_code (json);
+    sfr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_PRECONDITION_FAILED:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    sfr.hr.ec = TALER_JSON_get_error_code (json);
+    sfr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   default:
     /* unexpected response code */
     GNUNET_break_op (0);
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    sfr.hr.ec = TALER_JSON_get_error_code (json);
+    sfr.hr.hint = TALER_JSON_get_error_hint (json);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Unexpected response code %u/%d for exchange management set 
global fee\n",
                 (unsigned int) response_code,
-                (int) hr.ec);
+                (int) sfr.hr.ec);
     break;
   }
   if (NULL != sgfh->cb)
   {
     sgfh->cb (sgfh->cb_cls,
-              &hr);
+              &sfr);
     sgfh->cb = NULL;
   }
   TALER_EXCHANGE_management_set_global_fees_cancel (sgfh);
diff --git a/src/lib/exchange_api_management_set_wire_fee.c 
b/src/lib/exchange_api_management_set_wire_fee.c
index 72526116..01ed7742 100644
--- a/src/lib/exchange_api_management_set_wire_fee.c
+++ b/src/lib/exchange_api_management_set_wire_fee.c
@@ -79,9 +79,9 @@ handle_set_wire_fee_finished (void *cls,
 {
   struct TALER_EXCHANGE_ManagementSetWireFeeHandle *swfh = cls;
   const json_t *json = response;
-  struct TALER_EXCHANGE_HttpResponse hr = {
-    .http_status = (unsigned int) response_code,
-    .reply = json
+  struct TALER_EXCHANGE_ManagementSetWireFeeResponse swr = {
+    .hr.http_status = (unsigned int) response_code,
+    .hr.reply = json
   };
 
   swfh->job = NULL;
@@ -90,32 +90,32 @@ handle_set_wire_fee_finished (void *cls,
   case MHD_HTTP_NO_CONTENT:
     break;
   case MHD_HTTP_FORBIDDEN:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    swr.hr.ec = TALER_JSON_get_error_code (json);
+    swr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_CONFLICT:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    swr.hr.ec = TALER_JSON_get_error_code (json);
+    swr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_PRECONDITION_FAILED:
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    swr.hr.ec = TALER_JSON_get_error_code (json);
+    swr.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   default:
     /* unexpected response code */
     GNUNET_break_op (0);
-    hr.ec = TALER_JSON_get_error_code (json);
-    hr.hint = TALER_JSON_get_error_hint (json);
+    swr.hr.ec = TALER_JSON_get_error_code (json);
+    swr.hr.hint = TALER_JSON_get_error_hint (json);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Unexpected response code %u/%d for exchange management set 
wire fee\n",
                 (unsigned int) response_code,
-                (int) hr.ec);
+                (int) swr.hr.ec);
     break;
   }
   if (NULL != swfh->cb)
   {
     swfh->cb (swfh->cb_cls,
-              &hr);
+              &swr);
     swfh->cb = NULL;
   }
   TALER_EXCHANGE_management_set_wire_fees_cancel (swfh);
diff --git a/src/exchange-tools/taler-auditor-offline.c 
b/src/exchange-tools/taler-auditor-offline.c
index cd439d23..39495311 100644
--- a/src/exchange-tools/taler-auditor-offline.c
+++ b/src/exchange-tools/taler-auditor-offline.c
@@ -388,14 +388,15 @@ load_offline_key (int do_create)
  * add operation result.
  *
  * @param cls closure with a `struct DenominationAddRequest`
  * @param hr HTTP response data
  */
 static void
 denomination_add_cb (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr)
+  const struct TALER_EXCHANGE_AuditorAddDenominationResponse *adr)
 {
   struct DenominationAddRequest *dar = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &adr->hr;
 
   if (MHD_HTTP_NO_CONTENT != hr->http_status)
   {
@@ -388,14 +388,15 @@ load_offline_key (int do_create)
  *
  * @param cls closure with a `struct DenominationAddRequest`
- * @param hr HTTP response data
+ * @param adr response data
  */
 static void
diff --git a/src/exchange-tools/taler-exchange-offline.c 
b/src/exchange-tools/taler-exchange-offline.c
index 77c163c3..fed29437 100644
--- a/src/exchange-tools/taler-exchange-offline.c
+++ b/src/exchange-tools/taler-exchange-offline.c
@@ -1301,13 +1301,15 @@ upload_signkey_revocation (const char *exchange_url,
  * Function called with information about the post auditor add operation 
result.
  *
  * @param cls closure with a `struct AuditorAddRequest`
  * @param hr HTTP response data
  */
 static void
-auditor_add_cb (void *cls,
-                const struct TALER_EXCHANGE_HttpResponse *hr)
+auditor_add_cb (
+  void *cls,
+  const struct TALER_EXCHANGE_ManagementAuditorEnableResponse *mer)
 {
   struct AuditorAddRequest *aar = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &mer->hr;
 
   if (MHD_HTTP_NO_CONTENT != hr->http_status)
   {
@@ -1401,13 +1403,15 @@ upload_auditor_add (const char *exchange_url,
  * Function called with information about the post auditor del operation 
result.
  *
  * @param cls closure with a `struct AuditorDelRequest`
  * @param hr HTTP response data
  */
 static void
 auditor_del_cb (void *cls,
-                const struct TALER_EXCHANGE_HttpResponse *hr)
+                const struct
+                TALER_EXCHANGE_ManagementAuditorDisableResponse *mdr)
 {
   struct AuditorDelRequest *adr = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &mdr->hr;
 
   if (MHD_HTTP_NO_CONTENT != hr->http_status)
   {
@@ -1726,14 +1730,15 @@ upload_wire_del (const char *exchange_url,
  * Function called with information about the post wire fee operation result.
  *
  * @param cls closure with a `struct WireFeeRequest`
  * @param hr HTTP response data
  */
 static void
 wire_fee_cb (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr)
+  const struct TALER_EXCHANGE_ManagementSetWireFeeResponse *swr)
 {
   struct WireFeeRequest *wfr = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &swr->hr;
 
   if (MHD_HTTP_NO_CONTENT != hr->http_status)
   {
@@ -1831,14 +1836,15 @@ upload_wire_fee (const char *exchange_url,
  * Function called with information about the post global fee operation result.
  *
  * @param cls closure with a `struct WireFeeRequest`
- * @param hr HTTP response data
+ * @param gr response data
  */
 static void
 global_fee_cb (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr)
+  const struct TALER_EXCHANGE_ManagementSetGlobalFeeResponse *gr)
 {
   struct GlobalFeeRequest *gfr = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &gr->hr;
 
   if (MHD_HTTP_NO_CONTENT != hr->http_status)
   {
@@ -2358,14 +2364,15 @@ upload_extensions (const char *exchange_url,
  * Function called with information about the add partner operation.
  *
  * @param cls closure with a `struct PartnerAddRequest`
  * @param hr HTTP response data
  */
 static void
 add_partner_cb (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr)
+  const struct TALER_EXCHANGE_ManagementAddPartnerResponse *apr)
 {
   struct PartnerAddRequest *par = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &apr->hr;
 
   if (MHD_HTTP_NO_CONTENT != hr->http_status)
   {
@@ -1301,13 +1301,15 @@ upload_signkey_revocation (const char *exchange_url,
  *
  * @param cls closure with a `struct AuditorAddRequest`
- * @param hr HTTP response data
+ * @param mer response data
  */
 static void
@@ -1401,13 +1403,15 @@ upload_auditor_add (const char *exchange_url,
  *
  * @param cls closure with a `struct AuditorDelRequest`
- * @param hr HTTP response data
+ * @param mdr response data
  */
 static void
@@ -1726,14 +1730,15 @@ upload_wire_del (const char *exchange_url,
  *
  * @param cls closure with a `struct WireFeeRequest`
- * @param hr HTTP response data
+ * @param swr response data
  */
 static void
@@ -2358,14 +2364,15 @@ upload_extensions (const char *exchange_url,
  *
  * @param cls closure with a `struct PartnerAddRequest`
- * @param hr HTTP response data
+ * @param apr response data
  */
 static void
diff --git a/src/include/taler_exchange_service.h 
b/src/include/taler_exchange_service.h
index 5fcfa403..c6c1d3a1 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -4548,7 +4548,7 @@ struct TALER_EXCHANGE_ManagementPostExtensionsHandle *
 TALER_EXCHANGE_management_post_extensions (
   struct GNUNET_CURL_Context *ctx,
   const char *url,
-  struct TALER_EXCHANGE_ManagementPostExtensionsData *ped,
+  const struct TALER_EXCHANGE_ManagementPostExtensionsData *ped,
   TALER_EXCHANGE_ManagementPostExtensionsCallback cb,
   void *cb_cls);
 
@@ -5091,7 +5091,7 @@ TALER_EXCHANGE_lookup_aml_decision (
 
 
 /**
- * Cancel #TALER_EXCHANGE_add_aml_decision() operation.
+ * Cancel #TALER_EXCHANGE_lookup_aml_decision() operation.
  *
  * @param rh handle of the operation to cancel
  */
@@ -5105,18 +5105,30 @@ TALER_EXCHANGE_lookup_aml_decision_cancel (
  */
 struct TALER_EXCHANGE_AddAmlDecision;
 
+
+/**
+ * Response when making an AML decision.
+ */
+struct TALER_EXCHANGE_AddAmlDecisionResponse
+{
+  /**
+   * HTTP response data.
+   */
+  struct TALER_EXCHANGE_HttpResponse hr;
+};
+
+
 /**
  * Function called with information about storing an
  * an AML decision.
  *
  * @param cls closure
  * @param hr HTTP response data
  */
-// FIXME: bad API
 typedef void
 (*TALER_EXCHANGE_AddAmlDecisionCallback) (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr);
+  const struct TALER_EXCHANGE_AddAmlDecisionResponse *adr);
 
 /**
  * Inform the exchange that an AML decision has been taken.
@@ -5161,18 +5173,28 @@ TALER_EXCHANGE_add_aml_decision_cancel (
   struct TALER_EXCHANGE_AddAmlDecision *rh);
 
 
+/**
+ * Response when adding a partner exchange.
+ */
+struct TALER_EXCHANGE_ManagementAddPartnerResponse
+{
+  /**
+   * HTTP response data.
+   */
+  struct TALER_EXCHANGE_HttpResponse hr;
+};
+
 /**
  * Function called with information about the change to
  * an AML officer status.
  *
  * @param cls closure
  * @param hr HTTP response data
  */
-// FIXME: bad API
 typedef void
 (*TALER_EXCHANGE_ManagementAddPartnerCallback) (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr);
+  const struct TALER_EXCHANGE_ManagementAddPartnerResponse *apr);
 
 
 /**
@@ -5223,17 +5245,27 @@ TALER_EXCHANGE_management_add_partner_cancel (
   struct TALER_EXCHANGE_ManagementAddPartner *rh);
 
 
+/**
+ * Response when enabling an auditor.
+ */
+struct TALER_EXCHANGE_ManagementAuditorEnableResponse
+{
+  /**
+   * HTTP response data.
+   */
+  struct TALER_EXCHANGE_HttpResponse hr;
+};
+
 /**
  * Function called with information about the auditor setup operation result.
  *
  * @param cls closure
  * @param hr HTTP response data
  */
-// FIXME: bad API
 typedef void
 (*TALER_EXCHANGE_ManagementAuditorEnableCallback) (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr);
+  const struct TALER_EXCHANGE_ManagementAuditorEnableResponse *aer);
 
 
 /**
@@ -5278,18 +5310,27 @@ void
 TALER_EXCHANGE_management_enable_auditor_cancel (
   struct TALER_EXCHANGE_ManagementAuditorEnableHandle *ah);
 
+/**
+ * Response when disabling an auditor.
+ */
+struct TALER_EXCHANGE_ManagementAuditorDisableResponse
+{
+  /**
+   * HTTP response data.
+   */
+  struct TALER_EXCHANGE_HttpResponse hr;
+};
 
 /**
  * Function called with information about the auditor disable operation result.
  *
  * @param cls closure
  * @param hr HTTP response data
  */
-// FIXME: bad API
 typedef void
 (*TALER_EXCHANGE_ManagementAuditorDisableCallback) (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr);
+  const struct TALER_EXCHANGE_ManagementAuditorDisableResponse *adr);
 
 
 /**
@@ -5467,17 +5508,27 @@ TALER_EXCHANGE_management_disable_wire_cancel (
   struct TALER_EXCHANGE_ManagementWireDisableHandle *wh);
 
 
+/**
+ * Response when setting wire fees.
+ */
+struct TALER_EXCHANGE_ManagementSetWireFeeResponse
+{
+  /**
+   * HTTP response data.
+   */
+  struct TALER_EXCHANGE_HttpResponse hr;
+};
+
 /**
  * Function called with information about the wire enable operation result.
  *
  * @param cls closure
  * @param hr HTTP response data
  */
-// FIXME: bad API
 typedef void
 (*TALER_EXCHANGE_ManagementSetWireFeeCallback) (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr);
+  const struct TALER_EXCHANGE_ManagementSetWireFeeResponse *wfr);
 
 
 /**
@@ -5524,17 +5575,28 @@ TALER_EXCHANGE_management_set_wire_fees_cancel (
   struct TALER_EXCHANGE_ManagementSetWireFeeHandle *swfh);
 
 
+/**
+ * Response when setting global fees.
+ */
+struct TALER_EXCHANGE_ManagementSetGlobalFeeResponse
+{
+  /**
+   * HTTP response data.
+   */
+  struct TALER_EXCHANGE_HttpResponse hr;
+};
+
+
 /**
  * Function called with information about the global fee setting operation 
result.
  *
  * @param cls closure
  * @param hr HTTP response data
  */
-// FIXME: bad API
 typedef void
 (*TALER_EXCHANGE_ManagementSetGlobalFeeCallback) (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr);
+  const struct TALER_EXCHANGE_ManagementSetGlobalFeeResponse *gfr);
 
 
 /**
@@ -5585,18 +5647,29 @@ TALER_EXCHANGE_management_set_global_fees_cancel (
   struct TALER_EXCHANGE_ManagementSetGlobalFeeHandle *sgfh);
 
 
+/**
+ * Response when adding denomination signature by auditor.
+ */
+struct TALER_EXCHANGE_AuditorAddDenominationResponse
+{
+  /**
+   * HTTP response data.
+   */
+  struct TALER_EXCHANGE_HttpResponse hr;
+};
+
+
 /**
  * Function called with information about the POST
  * /auditor/$AUDITOR_PUB/$H_DENOM_PUB operation result.
  *
  * @param cls closure
  * @param hr HTTP response data
  */
-// FIXME: bad API
 typedef void
 (*TALER_EXCHANGE_AuditorAddDenominationCallback) (
   void *cls,
-  const struct TALER_EXCHANGE_HttpResponse *hr);
+  const struct TALER_EXCHANGE_AuditorAddDenominationResponse *adr);
 
 
 /**
@@ -5105,18 +5105,30 @@ TALER_EXCHANGE_lookup_aml_decision_cancel (
  *
  * @param cls closure
- * @param hr HTTP response data
+ * @param adr response data
  */
@@ -5161,18 +5173,28 @@ TALER_EXCHANGE_add_aml_decision_cancel (
  *
  * @param cls closure
- * @param hr HTTP response data
+ * @param apr response data
  */
@@ -5223,17 +5245,27 @@ TALER_EXCHANGE_management_add_partner_cancel (
  *
  * @param cls closure
- * @param hr HTTP response data
+ * @param aer response data
  */
@@ -5278,18 +5310,27 @@ void
  *
  * @param cls closure
- * @param hr HTTP response data
+ * @param adr HTTP response data
  */
@@ -5467,17 +5508,27 @@ TALER_EXCHANGE_management_disable_wire_cancel (
  *
  * @param cls closure
- * @param hr HTTP response data
+ * @param wfr response data
  */
@@ -5524,17 +5575,28 @@ TALER_EXCHANGE_management_set_wire_fees_cancel (
  *
  * @param cls closure
- * @param hr HTTP response data
+ * @param gfr HTTP response data
  */
@@ -5585,18 +5647,29 @@ TALER_EXCHANGE_management_set_global_fees_cancel (
  *
  * @param cls closure
- * @param hr HTTP response data
+ * @param adr HTTP response data
  */
diff --git a/src/testing/testing_api_cmd_auditor_add.c 
b/src/testing/testing_api_cmd_auditor_add.c
index 8362b66c..41182b7c 100644
--- a/src/testing/testing_api_cmd_auditor_add.c
+++ b/src/testing/testing_api_cmd_auditor_add.c
@@ -62,13 +62,15 @@ struct AuditorAddState
  * if the response code is acceptable.
  *
  * @param cls closure.
  * @param hr HTTP response details
  */
 static void
-auditor_add_cb (void *cls,
-                const struct TALER_EXCHANGE_HttpResponse *hr)
+auditor_add_cb (
+  void *cls,
+  const struct TALER_EXCHANGE_ManagementAuditorEnableResponse *aer)
 {
   struct AuditorAddState *ds = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &aer->hr;
 
   ds->dh = NULL;
   if (ds->expected_response_code != hr->http_status)
@@ -62,13 +62,15 @@ struct AuditorAddState
  *
  * @param cls closure.
- * @param hr HTTP response details
+ * @param aer response details
  */
 static void
diff --git a/src/testing/testing_api_cmd_auditor_add_denom_sig.c 
b/src/testing/testing_api_cmd_auditor_add_denom_sig.c
index 3d7ea82f..55b9f77a 100644
--- a/src/testing/testing_api_cmd_auditor_add_denom_sig.c
+++ b/src/testing/testing_api_cmd_auditor_add_denom_sig.c
@@ -67,13 +67,15 @@ struct AuditorAddDenomSigState
  * if the response code is acceptable.
  *
  * @param cls closure.
  * @param hr HTTP response details
  */
 static void
-denom_sig_add_cb (void *cls,
-                  const struct TALER_EXCHANGE_HttpResponse *hr)
+denom_sig_add_cb (
+  void *cls,
+  const struct TALER_EXCHANGE_AuditorAddDenominationResponse *adr)
 {
   struct AuditorAddDenomSigState *ds = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &adr->hr;
 
   ds->dh = NULL;
   if (ds->expected_response_code != hr->http_status)
@@ -67,13 +67,15 @@ struct AuditorAddDenomSigState
  *
  * @param cls closure.
- * @param hr HTTP response details
+ * @param adr response details
  */
 static void
diff --git a/src/testing/testing_api_cmd_auditor_del.c 
b/src/testing/testing_api_cmd_auditor_del.c
index de03d163..5bf77bb5 100644
--- a/src/testing/testing_api_cmd_auditor_del.c
+++ b/src/testing/testing_api_cmd_auditor_del.c
@@ -62,13 +62,16 @@ struct AuditorDelState
  * if the response code is acceptable.
  *
  * @param cls closure.
  * @param hr HTTP response details
  */
 static void
-auditor_del_cb (void *cls,
-                const struct TALER_EXCHANGE_HttpResponse *hr)
+auditor_del_cb (
+  void *cls,
+  const struct TALER_EXCHANGE_ManagementAuditorDisableResponse *adr)
+
 {
   struct AuditorDelState *ds = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &adr->hr;
 
   ds->dh = NULL;
   if (ds->expected_response_code != hr->http_status)
@@ -62,13 +62,16 @@ struct AuditorDelState
  *
  * @param cls closure.
- * @param hr HTTP response details
+ * @param adr response details
  */
 static void
diff --git a/src/testing/testing_api_cmd_set_wire_fee.c 
b/src/testing/testing_api_cmd_set_wire_fee.c
index ed3448ac..f0f76a87 100644
--- a/src/testing/testing_api_cmd_set_wire_fee.c
+++ b/src/testing/testing_api_cmd_set_wire_fee.c
@@ -77,13 +77,14 @@ struct WireFeeState
  * if the response code is acceptable.
  *
  * @param cls closure.
  * @param hr HTTP response details
  */
 static void
 wire_add_cb (void *cls,
-             const struct TALER_EXCHANGE_HttpResponse *hr)
+             const struct TALER_EXCHANGE_ManagementSetWireFeeResponse *sfr)
 {
   struct WireFeeState *ds = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &sfr->hr;
 
   ds->dh = NULL;
   if (ds->expected_response_code != hr->http_status)
@@ -77,13 +77,14 @@ struct WireFeeState
  *
  * @param cls closure.
- * @param hr HTTP response details
+ * @param sfr response details
  */
 static void
diff --git a/src/testing/testing_api_cmd_take_aml_decision.c 
b/src/testing/testing_api_cmd_take_aml_decision.c
index 21ba9af6..c355c686 100644
--- a/src/testing/testing_api_cmd_take_aml_decision.c
+++ b/src/testing/testing_api_cmd_take_aml_decision.c
@@ -90,17 +90,19 @@ struct AmlDecisionState
 
 
 /**
- * Callback to analyze the /management/XXX response, just used to check
+ * Callback to analyze the /aml-decision/$OFFICER_PUB response, just used to 
check
  * if the response code is acceptable.
  *
  * @param cls closure.
  * @param hr HTTP response details
  */
 static void
-take_aml_decision_cb (void *cls,
-                      const struct TALER_EXCHANGE_HttpResponse *hr)
+take_aml_decision_cb (
+  void *cls,
+  const struct TALER_EXCHANGE_AddAmlDecisionResponse *adr)
 {
   struct AmlDecisionState *ds = cls;
+  const struct TALER_EXCHANGE_HttpResponse *hr = &adr->hr;
 
   ds->dh = NULL;
   if (ds->expected_response != hr->http_status)
@@ -90,17 +90,19 @@ struct AmlDecisionState
  *
  * @param cls closure.
- * @param hr HTTP response details
+ * @param adr response details
  */
 static void

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]